package etu.sl213616;

import javafx.application.Application;
import javafx.fxml.FXML;
import javafx.scene.Scene;
import javafx.scene.control.Label;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuBar;
import javafx.scene.control.MenuItem;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.VBox;
import javafx.stage.FileChooser;
import javafx.stage.Stage;
import javafx.stage.FileChooser.ExtensionFilter;
import javafx.scene.control.TextInputDialog;
import java.io.File;
import java.util.Optional;

public class App2 extends Application {
    @FXML
    private VBox messageBox;  
    private Connexion connexion;  
    
    private Stage stage;

    @Override
    public void start(Stage stage) {
        this.stage = stage;
        BorderPane principal = new BorderPane();
        Scene scene = new Scene(principal, 640, 480);

        // Création de la barre de menu
        MenuBar menus = new MenuBar();

        // Création des menus principaux
        Menu menuFichier = new Menu("Fichiers");
        Menu menuFenetres = new Menu("Fenêtres");

        // Création des items de menu
        MenuItem choix = new MenuItem("Choisir un fichier");
        choix.setOnAction(event -> choisirFichier());
        MenuItem quitter = new MenuItem("Quitter");
        quitter.setOnAction(event -> quitterApplication());

        MenuItem connexionMenu = new MenuItem("Connexion");
        connexionMenu.setOnAction(event -> new FenetreConnexion(this).afficher());
        MenuItem deconnexionMenu = new MenuItem("Déconnexion");
        deconnexionMenu.setOnAction(event -> deconnecter());
        MenuItem ajoutV = new MenuItem("Ajouter une ville");
        ajoutV.setOnAction(event -> ajouterVille());

        // Ajout des items dans les menus
        menuFichier.getItems().addAll(choix, quitter);
        menuFenetres.getItems().addAll(connexionMenu, deconnexionMenu, ajoutV);

        // Ajout des menus dans la barre de menu
        menus.getMenus().addAll(menuFichier, menuFenetres);

        // Ajout de la barre de menu dans le haut de la fenêtre principale
        principal.setTop(menus);

        // Partie principale de la fenêtre (zone d'affichage des messages)
        messageBox = new VBox();
        principal.setCenter(messageBox);

        // Initialisation de la scène principale
        stage.setScene(scene);
        stage.setTitle("Application principale");
        stage.show();
    }

    // Affichage des messages cumulativement
    public void afficherMessage(String message) {
        Label newMessage = new Label(message);
        messageBox.getChildren().add(newMessage);
    }

    // Gérer la déconnexion
    private void deconnecter() {
        if (connexion != null) {
            afficherMessage("Déconnexion de " + connexion.getLogin());
            connexion.vider();
        } else {
            afficherMessage("Aucune connexion active");
        }
    }

    // Gérer la connexion
    public void validerConnexion(String nom, String password) {
        if (nom.isEmpty() || password.isEmpty()) {
            afficherMessage("Connexion annulée");
        } else {
            afficherMessage("Connexion réussie de " + nom);
            connexion = new Connexion(nom, password);  
        }
    }

    // Choisir un fichier
    private void choisirFichier() {
        FileChooser fileChooser = new FileChooser();
        fileChooser.getExtensionFilters().addAll(
                new ExtensionFilter("Fichiers Texte", "*.txt"),
                new ExtensionFilter("Fichiers PDF", "*.pdf"),
                new ExtensionFilter("Fichiers Java", "*.java"),
                new ExtensionFilter("Tous les fichiers", "*.*")
        );

        File file = fileChooser.showOpenDialog(stage);
        if (file != null) {
            afficherMessage("Chargement du fichier: " + file.getName());
        } else {
            afficherMessage("Aucun fichier sélectionné.");
        }
    }

    // Ajouter une ville
    private void ajouterVille() {
        TextInputDialog dialog = new TextInputDialog("Nom ville");
        dialog.setTitle("Ajouter une ville");
        dialog.setHeaderText("Veuillez saisir le nom de la ville");
        dialog.setContentText("Nom de la ville :");
        Optional<String> result = dialog.showAndWait();
        result.ifPresent(ville -> {
            afficherMessage("Ajout d'un nom de ville : " + ville);
        });
    }
    
 // Méthode pour définir la connexion
    public void setConnexion(Connexion connexion) {
        this.connexion = connexion;
    }

    // Quitter l'application
    private void quitterApplication() {
        afficherMessage("Fermeture de l'application.");
        System.exit(0);
    }
}
